@@ -1,6 +1,6 @@
 import numpy as np
 import pandas as pd
-from rs_metrics.parallel import user_mean
+from rs_metrics.parallel import user_mean, unique_items
 
 
 def _dcg_score(data):
@@ -82,3 +82,21 @@ def _mar(data):
 
 def mar(true, pred, k=10):
     return user_mean(_mar, true, pred, k)
+
+
+def item_pop(log, user_col='user_id', item_col='item_id'):
+    return log.groupby(item_col)[user_col].nunique().sort_values(ascending=False)
+
+
+def coverage(items, recs, k=None):
+    """What percentage of items appears in recommendations?
+
+    Args:
+        items: list of unique item ids
+        recs: dict of recommendations
+        k: topk items to use from recs
+
+    Returns: float
+    """
+    topk = unique_items(recs, k)
+    return pd.Series(items).isin(topk).mean()
